# Changelog

## 0.1.3

- Validate used method in trigger against the allowed methods from `method_information` in the info response.

## 0.1.2

- Set RabbitMQ queues to auto delete

## 0.1.1

- Fix [almabtrieb#7](https://codeberg.org/bovine/almabtrieb/issues/7)

## 0.1.0

Initial version
